@@ -5,23 +5,42 @@
 
 use strict;
 use warnings;
+use Path::Tiny;
+use Capture::Tiny 'capture';
+use Test::Differences;
+
+# normalize output and expected strings before eq test
+sub _normalize_expected {
+	my($text, $line_nr) = @_;
+	$text =~ s/__LOC__/at $0 line $line_nr/g;
+	return $text;
+}
+
+sub _normalize_output {
+	local($_) = @_;
+	s/\\/\//g;
+	s/\.$//gm;		# remove end "." from eval error message as it differs in perl versions
+	s/\S+(Text\/MacroScript\.pm line) \d+/$1 99/g;
+	s/(Open .*? failed: ).*( at.*)?/ $1."ERROR".($2 || "") /ge;
+	return $_;
+}
 
 #------------------------------------------------------------------------------
 # check $@ for the given error message, replace __LOC__ by the 
 # standard "at 'FILE' line DDD", normalize slashes for pathnames
 sub check_error {
-	my($line_nr, $eval, $expected) = @_;
+	my($line_nr, $eval, $exp_err) = @_;
 	my $where = "at line $line_nr";
 	
 	ok defined($eval), "error defined $where";
 	$eval //= "";
 	
-	$expected =~ s/__LOC__/at $0 line $line_nr/g;
-	for ($eval, $expected) {
-		s/\\/\//g;
+	$exp_err = _normalize_expected($exp_err, $line_nr);
+	for ($eval, $exp_err) {
+		$_ = _normalize_output($_);
 	}
 	
-	eq_or_diff $eval, $expected, "error ok $where";
+	eq_or_diff $eval, $exp_err, "error ok $where";
 }
 
 #------------------------------------------------------------------------------
@@ -42,10 +61,9 @@ sub t_capture {
 	
 	my($out,$err,$ret) = capture { $sub->() };
 
-	$exp_err =~ s/__LOC__/at $0 line $line_nr/g;
+	$exp_err = _normalize_expected($exp_err, $line_nr);
 	for ($err, $exp_err) {
-		s/\\/\//g;
-		s/\S+(Text\/MacroScript\.pm line) \d+/$1 99/g;
+		$_ = _normalize_output($_);
 	}
 	
 	eq_or_diff $out, $exp_out, "check stdout $where";
@@ -59,7 +77,7 @@ sub t_spew {
 	my($file, @lines) = @_;
 	path($file)->spew(@lines);
 	note "File $file:";
-	note path($file)->lines;
+	note @lines;
 }
 
 1;
